# AutoBridge

We are transiting into the new code base here. If you have any suggestions about the coding please let me know!

## Install for Development

```bash
python3.6 -m pip install --editable src
```